@@ -8,7 +8,7 @@
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
-#    
+#
 #    The above copyright notice and this permission notice shall be included in all
 # copies or substantial portions of the Software.
 #
@@ -55,32 +55,32 @@
 # -----------------------------------------------------------------------------
 
 #' Print log message to file or console.
-#' 
+#'
 #' This object is a stand-in for a logging object created by the
 #' logging module. RLY will use this by default to create things
 #' such as the parser.out file. If a user wants more detailed
 #' information, they can create their own logging object and pass
 #' it into RLY.
-#' ' 
+#' '
 #' @docType class
 #' @importFrom R6 R6Class
 #' @importFrom futile.logger flog.error flog.warn flog.info flog.debug
-#' @importFrom futile.logger flog.appender 
+#' @importFrom futile.logger flog.appender
 #' @importFrom futile.logger appender.console appender.file
 #' @format A \code{\link{R6Class}} object
-#' 
+#'
 #' @export
-#' 
+#'
 #' @examples
-#' debuglog <- RlyLogger$new(".", "file.out")
+#' debuglog <- rly::RlyLogger$new(".", "file.out")
 #' debuglog$info('This is info message')
-RlyLogger <- R6Class("RlyLogger",
+RlyLogger <- R6::R6Class("RlyLogger",
     public = list(
         name = NA,
         initialize = function(dir=NA, name=NA) {
           self$name <- randomString(4)
-          if(is.na(name)) flog.appender(appender.console(), name=self$name)
-          else            flog.appender(appender.file(name), name=self$name)
+          if(is.na(name)) futile.logger::flog.appender(appender.console(), name=self$name)
+          else            futile.logger::flog.appender(appender.file(name), name=self$name)
         },
         error = function(msg) { flog.error(msg, name=self$name) },
         warn  = function(msg) { flog.warn(msg, name=self$name) },
@@ -89,20 +89,20 @@ RlyLogger <- R6Class("RlyLogger",
     )
 )
 
-#' Null logger is used when no output should be generated. 
+#' Null logger is used when no output should be generated.
 #'
 #' Does nothing.
-#' 
+#'
 #' @docType class
 #' @importFrom R6 R6Class
 #' @format A \code{\link{R6Class}} object
-#' 
+#'
 #' @export
-#' 
+#'
 #' @examples
 #' debuglog <- NullLogger$new()
 #' debuglog$info('This will not print')
-NullLogger <- R6Class("NullLogger",
+NullLogger <- R6::R6Class("NullLogger",
     public = list(
         initialize = function(f) {
         },
@@ -111,4 +111,4 @@ NullLogger <- R6Class("NullLogger",
         info  = function(msg) { },
         debug = function(msg) { }
     )
-)
\ No newline at end of file
+)
